@@ -37,22 +37,6 @@ from hy.models import (
 from hy.reader import mangle, HyReader
 from hy.scoping import ResolveOuterVars, ScopeGlobal
 
-hy_ast_compile_flags = 0
-
-
-def ast_compile(a, filename, mode):
-    """Compile AST.
-
-    Args:
-        a (ast.AST): instance of `ast.AST`
-        filename (str): Filename used for run-time error messages
-        mode (str): `compile` mode parameter
-
-    Returns:
-        types.CodeType: instance of `types.CodeType`
-    """
-    return compile(a, filename, mode, hy_ast_compile_flags)
-
 
 def calling_module(n=1):
     """Get the module calling, if available.
@@ -422,7 +406,7 @@ class HyASTCompiler:
             # These are unexpected errors that will--hopefully--never be seen
             # by the user.
             f_exc = traceback.format_exc()
-            exc_msg = "Internal Compiler Bug 😱\n⤷ {}".format(f_exc)
+            exc_msg = "Internal Compiler Bug\n {}".format(f_exc)
             raise HyCompileError(exc_msg)
 
     def _syntax_error(self, expr, message):
@@ -698,7 +682,10 @@ class HyASTCompiler:
     def compile_list(self, expression):
         elts, ret, _ = self._compile_collect(expression)
         node = {List: asty.List, Set: asty.Set}[type(expression)]
-        return ret + node(expression, elts=elts, ctx=ast.Load())
+        return ret + node(
+            expression,
+            elts = elts,
+            **({} if node is asty.Set else dict(ctx = ast.Load())))
 
     @builds_model(Dict)
     def compile_dict(self, m):
@@ -763,10 +750,10 @@ def hy_eval(
         globals = module.__dict__
 
     # Two-step eval: eval() the body of the exec call
-    eval(ast_compile(_ast, filename, "exec"), globals, locals)
+    eval(compile(_ast, filename, "exec"), globals, locals)
 
     # Then eval the expression context and return that
-    return eval(ast_compile(expr, filename, "eval"), globals, locals)
+    return eval(compile(expr, filename, "eval"), globals, locals)
 
 
 def hy_eval_user(model, globals = None, locals = None, module = None, macros = None):
@@ -786,7 +773,7 @@ def hy_eval_user(model, globals = None, locals = None, module = None, macros = N
         (hy.eval '(my-test-mac) :module hyrule)  ; NameError
         (hy.eval '(list-n 3 1) :module hyrule)   ; => [1 1 1]
 
-    Finally, finer control of macro lookup can be achieved by passing in a dictionary of macros as the ``macros`` argument. The keys of this dictionary should be mangled macro names, and the values should be function objects to implement those macros. This is the same structure as is produced by :hy:func:`local-macros`, and in fact, ``(hy.eval … :macros (local-macros))`` is useful to make local macros visible to ``hy.eval``, which otherwise doesn't see them. ::
+    Finally, finer control of macro lookup can be achieved by passing in a dictionary of macros as the ``macros`` argument. The keys of this dictionary should be mangled macro names, and the values should be function objects to implement those macros. This is the same structure as is produced by :hy:func:`local-macros <hy.core.macros.local-macros>`, and in fact, ``(hy.eval … :macros (local-macros))`` is useful to make local macros visible to ``hy.eval``, which otherwise doesn't see them. ::
 
         (defn f []
           (defmacro lmac [] 1)
@@ -911,7 +898,9 @@ def hy_compile(
             body.append(ast.fix_missing_locations(ast.Import([ast.alias("hy", None)])))
 
     body += result.stmts
-    ret = root(body=body, type_ignores=[])
+    ret = root(
+        body = body,
+        **({} if root is ast.Interactive else dict(type_ignores = [])))
 
     if get_expr:
         expr = ast.Expression(body=expr)
